@@ -1,4 +1,4 @@
-from .nvp import NVP
+from .nvp import NVP as NVP
 
 
 print("EXPERIMENTAL WARNING: iesopt.alg.mga is an experimental module and its API may change in future releases.")
