@@ -3,10 +3,10 @@ import importlib.metadata
 from pathlib import Path
 
 from ..util import logger, set_iesopt_module_attr
-from .setup import setup_julia, import_modules
+from .setup import setup_julia, import_modules, use_existing_julia_environment
 
 
-def initialize(target: Path, sysimage: Path):
+def initialize(target: Path, sysimage: Path, *, reuse_julia_env: bool = False):
     if os.getenv("IESOPT_DOCS_NOEXEC"):
         logger.warning("Detected docs environment (env. var. `IESOPT_DOCS_NOEXEC` is set), skip loading Julia")
         return
@@ -15,7 +15,11 @@ def initialize(target: Path, sysimage: Path):
     logger.info("    © 2021 - now:  AIT Austrian Institute of Technology GmbH")
     logger.info("    Documentation: https://ait-energy.github.io/iesopt")
 
-    juliacall = setup_julia(target, sysimage)
+    if reuse_julia_env:
+        juliacall = use_existing_julia_environment(sysimage)
+    else:
+        juliacall = setup_julia(target, sysimage)
+
     julia = juliacall.Main
     set_iesopt_module_attr("julia", julia)
     set_iesopt_module_attr("juliacall", juliacall)
